from enum import Enum


class Timezone(str, Enum):
    AFRICAABIDJAN = "Africa/Abidjan"
    AFRICAACCRA = "Africa/Accra"
    AFRICAADDIS_ABABA = "Africa/Addis_Ababa"
    AFRICAALGIERS = "Africa/Algiers"
    AFRICAASMARA = "Africa/Asmara"
    AFRICAASMERA = "Africa/Asmera"
    AFRICABAMAKO = "Africa/Bamako"
    AFRICABANGUI = "Africa/Bangui"
    AFRICABANJUL = "Africa/Banjul"
    AFRICABISSAU = "Africa/Bissau"
    AFRICABLANTYRE = "Africa/Blantyre"
    AFRICABRAZZAVILLE = "Africa/Brazzaville"
    AFRICABUJUMBURA = "Africa/Bujumbura"
    AFRICACAIRO = "Africa/Cairo"
    AFRICACASABLANCA = "Africa/Casablanca"
    AFRICACEUTA = "Africa/Ceuta"
    AFRICACONAKRY = "Africa/Conakry"
    AFRICADAKAR = "Africa/Dakar"
    AFRICADAR_ES_SALAAM = "Africa/Dar_es_Salaam"
    AFRICADJIBOUTI = "Africa/Djibouti"
    AFRICADOUALA = "Africa/Douala"
    AFRICAEL_AAIUN = "Africa/El_Aaiun"
    AFRICAFREETOWN = "Africa/Freetown"
    AFRICAGABORONE = "Africa/Gaborone"
    AFRICAHARARE = "Africa/Harare"
    AFRICAJOHANNESBURG = "Africa/Johannesburg"
    AFRICAJUBA = "Africa/Juba"
    AFRICAKAMPALA = "Africa/Kampala"
    AFRICAKHARTOUM = "Africa/Khartoum"
    AFRICAKIGALI = "Africa/Kigali"
    AFRICAKINSHASA = "Africa/Kinshasa"
    AFRICALAGOS = "Africa/Lagos"
    AFRICALIBREVILLE = "Africa/Libreville"
    AFRICALOME = "Africa/Lome"
    AFRICALUANDA = "Africa/Luanda"
    AFRICALUBUMBASHI = "Africa/Lubumbashi"
    AFRICALUSAKA = "Africa/Lusaka"
    AFRICAMALABO = "Africa/Malabo"
    AFRICAMAPUTO = "Africa/Maputo"
    AFRICAMASERU = "Africa/Maseru"
    AFRICAMBABANE = "Africa/Mbabane"
    AFRICAMOGADISHU = "Africa/Mogadishu"
    AFRICAMONROVIA = "Africa/Monrovia"
    AFRICANAIROBI = "Africa/Nairobi"
    AFRICANDJAMENA = "Africa/Ndjamena"
    AFRICANIAMEY = "Africa/Niamey"
    AFRICANOUAKCHOTT = "Africa/Nouakchott"
    AFRICAOUAGADOUGOU = "Africa/Ouagadougou"
    AFRICAPORTO_NOVO = "Africa/Porto-Novo"
    AFRICASAO_TOME = "Africa/Sao_Tome"
    AFRICATIMBUKTU = "Africa/Timbuktu"
    AFRICATRIPOLI = "Africa/Tripoli"
    AFRICATUNIS = "Africa/Tunis"
    AFRICAWINDHOEK = "Africa/Windhoek"
    AMERICAADAK = "America/Adak"
    AMERICAANCHORAGE = "America/Anchorage"
    AMERICAANGUILLA = "America/Anguilla"
    AMERICAANTIGUA = "America/Antigua"
    AMERICAARAGUAINA = "America/Araguaina"
    AMERICAARGENTINABUENOS_AIRES = "America/Argentina/Buenos_Aires"
    AMERICAARGENTINACATAMARCA = "America/Argentina/Catamarca"
    AMERICAARGENTINACOMODRIVADAVIA = "America/Argentina/ComodRivadavia"
    AMERICAARGENTINACORDOBA = "America/Argentina/Cordoba"
    AMERICAARGENTINAJUJUY = "America/Argentina/Jujuy"
    AMERICAARGENTINALA_RIOJA = "America/Argentina/La_Rioja"
    AMERICAARGENTINAMENDOZA = "America/Argentina/Mendoza"
    AMERICAARGENTINARIO_GALLEGOS = "America/Argentina/Rio_Gallegos"
    AMERICAARGENTINASALTA = "America/Argentina/Salta"
    AMERICAARGENTINASAN_JUAN = "America/Argentina/San_Juan"
    AMERICAARGENTINASAN_LUIS = "America/Argentina/San_Luis"
    AMERICAARGENTINATUCUMAN = "America/Argentina/Tucuman"
    AMERICAARGENTINAUSHUAIA = "America/Argentina/Ushuaia"
    AMERICAARUBA = "America/Aruba"
    AMERICAASUNCION = "America/Asuncion"
    AMERICAATIKOKAN = "America/Atikokan"
    AMERICAATKA = "America/Atka"
    AMERICABAHIA = "America/Bahia"
    AMERICABAHIA_BANDERAS = "America/Bahia_Banderas"
    AMERICABARBADOS = "America/Barbados"
    AMERICABELEM = "America/Belem"
    AMERICABELIZE = "America/Belize"
    AMERICABLANC_SABLON = "America/Blanc-Sablon"
    AMERICABOA_VISTA = "America/Boa_Vista"
    AMERICABOGOTA = "America/Bogota"
    AMERICABOISE = "America/Boise"
    AMERICABUENOS_AIRES = "America/Buenos_Aires"
    AMERICACAMBRIDGE_BAY = "America/Cambridge_Bay"
    AMERICACAMPO_GRANDE = "America/Campo_Grande"
    AMERICACANCUN = "America/Cancun"
    AMERICACARACAS = "America/Caracas"
    AMERICACATAMARCA = "America/Catamarca"
    AMERICACAYENNE = "America/Cayenne"
    AMERICACAYMAN = "America/Cayman"
    AMERICACHICAGO = "America/Chicago"
    AMERICACHIHUAHUA = "America/Chihuahua"
    AMERICACORAL_HARBOUR = "America/Coral_Harbour"
    AMERICACORDOBA = "America/Cordoba"
    AMERICACOSTA_RICA = "America/Costa_Rica"
    AMERICACRESTON = "America/Creston"
    AMERICACUIABA = "America/Cuiaba"
    AMERICACURACAO = "America/Curacao"
    AMERICADANMARKSHAVN = "America/Danmarkshavn"
    AMERICADAWSON = "America/Dawson"
    AMERICADAWSON_CREEK = "America/Dawson_Creek"
    AMERICADENVER = "America/Denver"
    AMERICADETROIT = "America/Detroit"
    AMERICADOMINICA = "America/Dominica"
    AMERICAEDMONTON = "America/Edmonton"
    AMERICAEIRUNEPE = "America/Eirunepe"
    AMERICAEL_SALVADOR = "America/El_Salvador"
    AMERICAENSENADA = "America/Ensenada"
    AMERICAFORT_NELSON = "America/Fort_Nelson"
    AMERICAFORT_WAYNE = "America/Fort_Wayne"
    AMERICAFORTALEZA = "America/Fortaleza"
    AMERICAGLACE_BAY = "America/Glace_Bay"
    AMERICAGODTHAB = "America/Godthab"
    AMERICAGOOSE_BAY = "America/Goose_Bay"
    AMERICAGRAND_TURK = "America/Grand_Turk"
    AMERICAGRENADA = "America/Grenada"
    AMERICAGUADELOUPE = "America/Guadeloupe"
    AMERICAGUATEMALA = "America/Guatemala"
    AMERICAGUAYAQUIL = "America/Guayaquil"
    AMERICAGUYANA = "America/Guyana"
    AMERICAHALIFAX = "America/Halifax"
    AMERICAHAVANA = "America/Havana"
    AMERICAHERMOSILLO = "America/Hermosillo"
    AMERICAINDIANAINDIANAPOLIS = "America/Indiana/Indianapolis"
    AMERICAINDIANAKNOX = "America/Indiana/Knox"
    AMERICAINDIANAMARENGO = "America/Indiana/Marengo"
    AMERICAINDIANAPETERSBURG = "America/Indiana/Petersburg"
    AMERICAINDIANATELL_CITY = "America/Indiana/Tell_City"
    AMERICAINDIANAVEVAY = "America/Indiana/Vevay"
    AMERICAINDIANAVINCENNES = "America/Indiana/Vincennes"
    AMERICAINDIANAWINAMAC = "America/Indiana/Winamac"
    AMERICAINDIANAPOLIS = "America/Indianapolis"
    AMERICAINUVIK = "America/Inuvik"
    AMERICAIQALUIT = "America/Iqaluit"
    AMERICAJAMAICA = "America/Jamaica"
    AMERICAJUJUY = "America/Jujuy"
    AMERICAJUNEAU = "America/Juneau"
    AMERICAKENTUCKYLOUISVILLE = "America/Kentucky/Louisville"
    AMERICAKENTUCKYMONTICELLO = "America/Kentucky/Monticello"
    AMERICAKNOX_IN = "America/Knox_IN"
    AMERICAKRALENDIJK = "America/Kralendijk"
    AMERICALA_PAZ = "America/La_Paz"
    AMERICALIMA = "America/Lima"
    AMERICALOS_ANGELES = "America/Los_Angeles"
    AMERICALOUISVILLE = "America/Louisville"
    AMERICALOWER_PRINCES = "America/Lower_Princes"
    AMERICAMACEIO = "America/Maceio"
    AMERICAMANAGUA = "America/Managua"
    AMERICAMANAUS = "America/Manaus"
    AMERICAMARIGOT = "America/Marigot"
    AMERICAMARTINIQUE = "America/Martinique"
    AMERICAMATAMOROS = "America/Matamoros"
    AMERICAMAZATLAN = "America/Mazatlan"
    AMERICAMENDOZA = "America/Mendoza"
    AMERICAMENOMINEE = "America/Menominee"
    AMERICAMERIDA = "America/Merida"
    AMERICAMETLAKATLA = "America/Metlakatla"
    AMERICAMEXICO_CITY = "America/Mexico_City"
    AMERICAMIQUELON = "America/Miquelon"
    AMERICAMONCTON = "America/Moncton"
    AMERICAMONTERREY = "America/Monterrey"
    AMERICAMONTEVIDEO = "America/Montevideo"
    AMERICAMONTREAL = "America/Montreal"
    AMERICAMONTSERRAT = "America/Montserrat"
    AMERICANASSAU = "America/Nassau"
    AMERICANEW_YORK = "America/New_York"
    AMERICANIPIGON = "America/Nipigon"
    AMERICANOME = "America/Nome"
    AMERICANORONHA = "America/Noronha"
    AMERICANORTH_DAKOTABEULAH = "America/North_Dakota/Beulah"
    AMERICANORTH_DAKOTACENTER = "America/North_Dakota/Center"
    AMERICANORTH_DAKOTANEW_SALEM = "America/North_Dakota/New_Salem"
    AMERICANUUK = "America/Nuuk"
    AMERICAOJINAGA = "America/Ojinaga"
    AMERICAPANAMA = "America/Panama"
    AMERICAPANGNIRTUNG = "America/Pangnirtung"
    AMERICAPARAMARIBO = "America/Paramaribo"
    AMERICAPHOENIX = "America/Phoenix"
    AMERICAPORT_AU_PRINCE = "America/Port-au-Prince"
    AMERICAPORT_OF_SPAIN = "America/Port_of_Spain"
    AMERICAPORTO_ACRE = "America/Porto_Acre"
    AMERICAPORTO_VELHO = "America/Porto_Velho"
    AMERICAPUERTO_RICO = "America/Puerto_Rico"
    AMERICAPUNTA_ARENAS = "America/Punta_Arenas"
    AMERICARAINY_RIVER = "America/Rainy_River"
    AMERICARANKIN_INLET = "America/Rankin_Inlet"
    AMERICARECIFE = "America/Recife"
    AMERICAREGINA = "America/Regina"
    AMERICARESOLUTE = "America/Resolute"
    AMERICARIO_BRANCO = "America/Rio_Branco"
    AMERICAROSARIO = "America/Rosario"
    AMERICASANTA_ISABEL = "America/Santa_Isabel"
    AMERICASANTAREM = "America/Santarem"
    AMERICASANTIAGO = "America/Santiago"
    AMERICASANTO_DOMINGO = "America/Santo_Domingo"
    AMERICASAO_PAULO = "America/Sao_Paulo"
    AMERICASCORESBYSUND = "America/Scoresbysund"
    AMERICASHIPROCK = "America/Shiprock"
    AMERICASITKA = "America/Sitka"
    AMERICAST_BARTHELEMY = "America/St_Barthelemy"
    AMERICAST_JOHNS = "America/St_Johns"
    AMERICAST_KITTS = "America/St_Kitts"
    AMERICAST_LUCIA = "America/St_Lucia"
    AMERICAST_THOMAS = "America/St_Thomas"
    AMERICAST_VINCENT = "America/St_Vincent"
    AMERICASWIFT_CURRENT = "America/Swift_Current"
    AMERICATEGUCIGALPA = "America/Tegucigalpa"
    AMERICATHULE = "America/Thule"
    AMERICATHUNDER_BAY = "America/Thunder_Bay"
    AMERICATIJUANA = "America/Tijuana"
    AMERICATORONTO = "America/Toronto"
    AMERICATORTOLA = "America/Tortola"
    AMERICAVANCOUVER = "America/Vancouver"
    AMERICAVIRGIN = "America/Virgin"
    AMERICAWHITEHORSE = "America/Whitehorse"
    AMERICAWINNIPEG = "America/Winnipeg"
    AMERICAYAKUTAT = "America/Yakutat"
    AMERICAYELLOWKNIFE = "America/Yellowknife"
    ANTARCTICACASEY = "Antarctica/Casey"
    ANTARCTICADAVIS = "Antarctica/Davis"
    ANTARCTICADUMONTDURVILLE = "Antarctica/DumontDUrville"
    ANTARCTICAMACQUARIE = "Antarctica/Macquarie"
    ANTARCTICAMAWSON = "Antarctica/Mawson"
    ANTARCTICAMCMURDO = "Antarctica/McMurdo"
    ANTARCTICAPALMER = "Antarctica/Palmer"
    ANTARCTICAROTHERA = "Antarctica/Rothera"
    ANTARCTICASOUTH_POLE = "Antarctica/South_Pole"
    ANTARCTICASYOWA = "Antarctica/Syowa"
    ANTARCTICATROLL = "Antarctica/Troll"
    ANTARCTICAVOSTOK = "Antarctica/Vostok"
    ARCTICLONGYEARBYEN = "Arctic/Longyearbyen"
    ASIAADEN = "Asia/Aden"
    ASIAALMATY = "Asia/Almaty"
    ASIAAMMAN = "Asia/Amman"
    ASIAANADYR = "Asia/Anadyr"
    ASIAAQTAU = "Asia/Aqtau"
    ASIAAQTOBE = "Asia/Aqtobe"
    ASIAASHGABAT = "Asia/Ashgabat"
    ASIAASHKHABAD = "Asia/Ashkhabad"
    ASIAATYRAU = "Asia/Atyrau"
    ASIABAGHDAD = "Asia/Baghdad"
    ASIABAHRAIN = "Asia/Bahrain"
    ASIABAKU = "Asia/Baku"
    ASIABANGKOK = "Asia/Bangkok"
    ASIABARNAUL = "Asia/Barnaul"
    ASIABEIRUT = "Asia/Beirut"
    ASIABISHKEK = "Asia/Bishkek"
    ASIABRUNEI = "Asia/Brunei"
    ASIACALCUTTA = "Asia/Calcutta"
    ASIACHITA = "Asia/Chita"
    ASIACHOIBALSAN = "Asia/Choibalsan"
    ASIACHONGQING = "Asia/Chongqing"
    ASIACHUNGKING = "Asia/Chungking"
    ASIACOLOMBO = "Asia/Colombo"
    ASIADACCA = "Asia/Dacca"
    ASIADAMASCUS = "Asia/Damascus"
    ASIADHAKA = "Asia/Dhaka"
    ASIADILI = "Asia/Dili"
    ASIADUBAI = "Asia/Dubai"
    ASIADUSHANBE = "Asia/Dushanbe"
    ASIAFAMAGUSTA = "Asia/Famagusta"
    ASIAGAZA = "Asia/Gaza"
    ASIAHARBIN = "Asia/Harbin"
    ASIAHEBRON = "Asia/Hebron"
    ASIAHO_CHI_MINH = "Asia/Ho_Chi_Minh"
    ASIAHONG_KONG = "Asia/Hong_Kong"
    ASIAHOVD = "Asia/Hovd"
    ASIAIRKUTSK = "Asia/Irkutsk"
    ASIAISTANBUL = "Asia/Istanbul"
    ASIAJAKARTA = "Asia/Jakarta"
    ASIAJAYAPURA = "Asia/Jayapura"
    ASIAJERUSALEM = "Asia/Jerusalem"
    ASIAKABUL = "Asia/Kabul"
    ASIAKAMCHATKA = "Asia/Kamchatka"
    ASIAKARACHI = "Asia/Karachi"
    ASIAKASHGAR = "Asia/Kashgar"
    ASIAKATHMANDU = "Asia/Kathmandu"
    ASIAKATMANDU = "Asia/Katmandu"
    ASIAKHANDYGA = "Asia/Khandyga"
    ASIAKOLKATA = "Asia/Kolkata"
    ASIAKRASNOYARSK = "Asia/Krasnoyarsk"
    ASIAKUALA_LUMPUR = "Asia/Kuala_Lumpur"
    ASIAKUCHING = "Asia/Kuching"
    ASIAKUWAIT = "Asia/Kuwait"
    ASIAMACAO = "Asia/Macao"
    ASIAMACAU = "Asia/Macau"
    ASIAMAGADAN = "Asia/Magadan"
    ASIAMAKASSAR = "Asia/Makassar"
    ASIAMANILA = "Asia/Manila"
    ASIAMUSCAT = "Asia/Muscat"
    ASIANICOSIA = "Asia/Nicosia"
    ASIANOVOKUZNETSK = "Asia/Novokuznetsk"
    ASIANOVOSIBIRSK = "Asia/Novosibirsk"
    ASIAOMSK = "Asia/Omsk"
    ASIAORAL = "Asia/Oral"
    ASIAPHNOM_PENH = "Asia/Phnom_Penh"
    ASIAPONTIANAK = "Asia/Pontianak"
    ASIAPYONGYANG = "Asia/Pyongyang"
    ASIAQATAR = "Asia/Qatar"
    ASIAQOSTANAY = "Asia/Qostanay"
    ASIAQYZYLORDA = "Asia/Qyzylorda"
    ASIARANGOON = "Asia/Rangoon"
    ASIARIYADH = "Asia/Riyadh"
    ASIASAIGON = "Asia/Saigon"
    ASIASAKHALIN = "Asia/Sakhalin"
    ASIASAMARKAND = "Asia/Samarkand"
    ASIASEOUL = "Asia/Seoul"
    ASIASHANGHAI = "Asia/Shanghai"
    ASIASINGAPORE = "Asia/Singapore"
    ASIASREDNEKOLYMSK = "Asia/Srednekolymsk"
    ASIATAIPEI = "Asia/Taipei"
    ASIATASHKENT = "Asia/Tashkent"
    ASIATBILISI = "Asia/Tbilisi"
    ASIATEHRAN = "Asia/Tehran"
    ASIATEL_AVIV = "Asia/Tel_Aviv"
    ASIATHIMBU = "Asia/Thimbu"
    ASIATHIMPHU = "Asia/Thimphu"
    ASIATOKYO = "Asia/Tokyo"
    ASIATOMSK = "Asia/Tomsk"
    ASIAUJUNG_PANDANG = "Asia/Ujung_Pandang"
    ASIAULAANBAATAR = "Asia/Ulaanbaatar"
    ASIAULAN_BATOR = "Asia/Ulan_Bator"
    ASIAURUMQI = "Asia/Urumqi"
    ASIAUST_NERA = "Asia/Ust-Nera"
    ASIAVIENTIANE = "Asia/Vientiane"
    ASIAVLADIVOSTOK = "Asia/Vladivostok"
    ASIAYAKUTSK = "Asia/Yakutsk"
    ASIAYANGON = "Asia/Yangon"
    ASIAYEKATERINBURG = "Asia/Yekaterinburg"
    ASIAYEREVAN = "Asia/Yerevan"
    ATLANTICAZORES = "Atlantic/Azores"
    ATLANTICBERMUDA = "Atlantic/Bermuda"
    ATLANTICCANARY = "Atlantic/Canary"
    ATLANTICCAPE_VERDE = "Atlantic/Cape_Verde"
    ATLANTICFAEROE = "Atlantic/Faeroe"
    ATLANTICFAROE = "Atlantic/Faroe"
    ATLANTICJAN_MAYEN = "Atlantic/Jan_Mayen"
    ATLANTICMADEIRA = "Atlantic/Madeira"
    ATLANTICREYKJAVIK = "Atlantic/Reykjavik"
    ATLANTICSOUTH_GEORGIA = "Atlantic/South_Georgia"
    ATLANTICST_HELENA = "Atlantic/St_Helena"
    ATLANTICSTANLEY = "Atlantic/Stanley"
    AUSTRALIAACT = "Australia/ACT"
    AUSTRALIAADELAIDE = "Australia/Adelaide"
    AUSTRALIABRISBANE = "Australia/Brisbane"
    AUSTRALIABROKEN_HILL = "Australia/Broken_Hill"
    AUSTRALIACANBERRA = "Australia/Canberra"
    AUSTRALIACURRIE = "Australia/Currie"
    AUSTRALIADARWIN = "Australia/Darwin"
    AUSTRALIAEUCLA = "Australia/Eucla"
    AUSTRALIAHOBART = "Australia/Hobart"
    AUSTRALIALHI = "Australia/LHI"
    AUSTRALIALINDEMAN = "Australia/Lindeman"
    AUSTRALIALORD_HOWE = "Australia/Lord_Howe"
    AUSTRALIAMELBOURNE = "Australia/Melbourne"
    AUSTRALIANSW = "Australia/NSW"
    AUSTRALIANORTH = "Australia/North"
    AUSTRALIAPERTH = "Australia/Perth"
    AUSTRALIAQUEENSLAND = "Australia/Queensland"
    AUSTRALIASOUTH = "Australia/South"
    AUSTRALIASYDNEY = "Australia/Sydney"
    AUSTRALIATASMANIA = "Australia/Tasmania"
    AUSTRALIAVICTORIA = "Australia/Victoria"
    AUSTRALIAWEST = "Australia/West"
    AUSTRALIAYANCOWINNA = "Australia/Yancowinna"
    BRAZILACRE = "Brazil/Acre"
    BRAZILDENORONHA = "Brazil/DeNoronha"
    BRAZILEAST = "Brazil/East"
    BRAZILWEST = "Brazil/West"
    CET = "CET"
    C_S_T6_CDT = "CST6CDT"
    CANADAATLANTIC = "Canada/Atlantic"
    CANADACENTRAL = "Canada/Central"
    CANADAEASTERN = "Canada/Eastern"
    CANADAMOUNTAIN = "Canada/Mountain"
    CANADANEWFOUNDLAND = "Canada/Newfoundland"
    CANADAPACIFIC = "Canada/Pacific"
    CANADASASKATCHEWAN = "Canada/Saskatchewan"
    CANADAYUKON = "Canada/Yukon"
    CHILECONTINENTAL = "Chile/Continental"
    CHILEEASTERISLAND = "Chile/EasterIsland"
    CUBA = "Cuba"
    EET = "EET"
    EST = "EST"
    E_S_T5_EDT = "EST5EDT"
    EGYPT = "Egypt"
    EIRE = "Eire"
    E_T_C_G_M_T0 = "Etc/GMT0"
    ETCGREENWICH = "Etc/Greenwich"
    ETCUCT = "Etc/UCT"
    ETCUTC = "Etc/UTC"
    ETCUNIVERSAL = "Etc/Universal"
    ETCZULU = "Etc/Zulu"
    EUROPEAMSTERDAM = "Europe/Amsterdam"
    EUROPEANDORRA = "Europe/Andorra"
    EUROPEASTRAKHAN = "Europe/Astrakhan"
    EUROPEATHENS = "Europe/Athens"
    EUROPEBELFAST = "Europe/Belfast"
    EUROPEBELGRADE = "Europe/Belgrade"
    EUROPEBERLIN = "Europe/Berlin"
    EUROPEBRATISLAVA = "Europe/Bratislava"
    EUROPEBRUSSELS = "Europe/Brussels"
    EUROPEBUCHAREST = "Europe/Bucharest"
    EUROPEBUDAPEST = "Europe/Budapest"
    EUROPEBUSINGEN = "Europe/Busingen"
    EUROPECHISINAU = "Europe/Chisinau"
    EUROPECOPENHAGEN = "Europe/Copenhagen"
    EUROPEDUBLIN = "Europe/Dublin"
    EUROPEGIBRALTAR = "Europe/Gibraltar"
    EUROPEGUERNSEY = "Europe/Guernsey"
    EUROPEHELSINKI = "Europe/Helsinki"
    EUROPEISLE_OF_MAN = "Europe/Isle_of_Man"
    EUROPEISTANBUL = "Europe/Istanbul"
    EUROPEJERSEY = "Europe/Jersey"
    EUROPEKALININGRAD = "Europe/Kaliningrad"
    EUROPEKIEV = "Europe/Kiev"
    EUROPEKIROV = "Europe/Kirov"
    EUROPELISBON = "Europe/Lisbon"
    EUROPELJUBLJANA = "Europe/Ljubljana"
    EUROPELONDON = "Europe/London"
    EUROPELUXEMBOURG = "Europe/Luxembourg"
    EUROPEMADRID = "Europe/Madrid"
    EUROPEMALTA = "Europe/Malta"
    EUROPEMARIEHAMN = "Europe/Mariehamn"
    EUROPEMINSK = "Europe/Minsk"
    EUROPEMONACO = "Europe/Monaco"
    EUROPEMOSCOW = "Europe/Moscow"
    EUROPENICOSIA = "Europe/Nicosia"
    EUROPEOSLO = "Europe/Oslo"
    EUROPEPARIS = "Europe/Paris"
    EUROPEPODGORICA = "Europe/Podgorica"
    EUROPEPRAGUE = "Europe/Prague"
    EUROPERIGA = "Europe/Riga"
    EUROPEROME = "Europe/Rome"
    EUROPESAMARA = "Europe/Samara"
    EUROPESAN_MARINO = "Europe/San_Marino"
    EUROPESARAJEVO = "Europe/Sarajevo"
    EUROPESARATOV = "Europe/Saratov"
    EUROPESIMFEROPOL = "Europe/Simferopol"
    EUROPESKOPJE = "Europe/Skopje"
    EUROPESOFIA = "Europe/Sofia"
    EUROPESTOCKHOLM = "Europe/Stockholm"
    EUROPETALLINN = "Europe/Tallinn"
    EUROPETIRANE = "Europe/Tirane"
    EUROPETIRASPOL = "Europe/Tiraspol"
    EUROPEULYANOVSK = "Europe/Ulyanovsk"
    EUROPEUZHGOROD = "Europe/Uzhgorod"
    EUROPEVADUZ = "Europe/Vaduz"
    EUROPEVATICAN = "Europe/Vatican"
    EUROPEVIENNA = "Europe/Vienna"
    EUROPEVILNIUS = "Europe/Vilnius"
    EUROPEVOLGOGRAD = "Europe/Volgograd"
    EUROPEWARSAW = "Europe/Warsaw"
    EUROPEZAGREB = "Europe/Zagreb"
    EUROPEZAPOROZHYE = "Europe/Zaporozhye"
    EUROPEZURICH = "Europe/Zurich"
    GB = "GB"
    GB_EIRE = "GB-Eire"
    G_M_T0 = "GMT0"
    GREENWICH = "Greenwich"
    HST = "HST"
    HONGKONG = "Hongkong"
    ICELAND = "Iceland"
    INDIANANTANANARIVO = "Indian/Antananarivo"
    INDIANCHAGOS = "Indian/Chagos"
    INDIANCHRISTMAS = "Indian/Christmas"
    INDIANCOCOS = "Indian/Cocos"
    INDIANCOMORO = "Indian/Comoro"
    INDIANKERGUELEN = "Indian/Kerguelen"
    INDIANMAHE = "Indian/Mahe"
    INDIANMALDIVES = "Indian/Maldives"
    INDIANMAURITIUS = "Indian/Mauritius"
    INDIANMAYOTTE = "Indian/Mayotte"
    INDIANREUNION = "Indian/Reunion"
    IRAN = "Iran"
    ISRAEL = "Israel"
    JAMAICA = "Jamaica"
    JAPAN = "Japan"
    KWAJALEIN = "Kwajalein"
    LIBYA = "Libya"
    MET = "MET"
    MST = "MST"
    M_S_T7_MDT = "MST7MDT"
    MEXICOBAJANORTE = "Mexico/BajaNorte"
    MEXICOBAJASUR = "Mexico/BajaSur"
    MEXICOGENERAL = "Mexico/General"
    NZ = "NZ"
    NZ_CHAT = "NZ-CHAT"
    NAVAJO = "Navajo"
    PRC = "PRC"
    P_S_T8_PDT = "PST8PDT"
    PACIFICAPIA = "Pacific/Apia"
    PACIFICAUCKLAND = "Pacific/Auckland"
    PACIFICBOUGAINVILLE = "Pacific/Bougainville"
    PACIFICCHATHAM = "Pacific/Chatham"
    PACIFICCHUUK = "Pacific/Chuuk"
    PACIFICEASTER = "Pacific/Easter"
    PACIFICEFATE = "Pacific/Efate"
    PACIFICENDERBURY = "Pacific/Enderbury"
    PACIFICFAKAOFO = "Pacific/Fakaofo"
    PACIFICFIJI = "Pacific/Fiji"
    PACIFICFUNAFUTI = "Pacific/Funafuti"
    PACIFICGALAPAGOS = "Pacific/Galapagos"
    PACIFICGAMBIER = "Pacific/Gambier"
    PACIFICGUADALCANAL = "Pacific/Guadalcanal"
    PACIFICGUAM = "Pacific/Guam"
    PACIFICHONOLULU = "Pacific/Honolulu"
    PACIFICJOHNSTON = "Pacific/Johnston"
    PACIFICKIRITIMATI = "Pacific/Kiritimati"
    PACIFICKOSRAE = "Pacific/Kosrae"
    PACIFICKWAJALEIN = "Pacific/Kwajalein"
    PACIFICMAJURO = "Pacific/Majuro"
    PACIFICMARQUESAS = "Pacific/Marquesas"
    PACIFICMIDWAY = "Pacific/Midway"
    PACIFICNAURU = "Pacific/Nauru"
    PACIFICNIUE = "Pacific/Niue"
    PACIFICNORFOLK = "Pacific/Norfolk"
    PACIFICNOUMEA = "Pacific/Noumea"
    PACIFICPAGO_PAGO = "Pacific/Pago_Pago"
    PACIFICPALAU = "Pacific/Palau"
    PACIFICPITCAIRN = "Pacific/Pitcairn"
    PACIFICPOHNPEI = "Pacific/Pohnpei"
    PACIFICPONAPE = "Pacific/Ponape"
    PACIFICPORT_MORESBY = "Pacific/Port_Moresby"
    PACIFICRAROTONGA = "Pacific/Rarotonga"
    PACIFICSAIPAN = "Pacific/Saipan"
    PACIFICSAMOA = "Pacific/Samoa"
    PACIFICTAHITI = "Pacific/Tahiti"
    PACIFICTARAWA = "Pacific/Tarawa"
    PACIFICTONGATAPU = "Pacific/Tongatapu"
    PACIFICTRUK = "Pacific/Truk"
    PACIFICWAKE = "Pacific/Wake"
    PACIFICWALLIS = "Pacific/Wallis"
    PACIFICYAP = "Pacific/Yap"
    POLAND = "Poland"
    PORTUGAL = "Portugal"
    ROC = "ROC"
    ROK = "ROK"
    SINGAPORE = "Singapore"
    TURKEY = "Turkey"
    UCT = "UCT"
    USALASKA = "US/Alaska"
    USALEUTIAN = "US/Aleutian"
    USARIZONA = "US/Arizona"
    USCENTRAL = "US/Central"
    USEAST_INDIANA = "US/East-Indiana"
    USEASTERN = "US/Eastern"
    USHAWAII = "US/Hawaii"
    USINDIANA_STARKE = "US/Indiana-Starke"
    USMICHIGAN = "US/Michigan"
    USMOUNTAIN = "US/Mountain"
    USPACIFIC = "US/Pacific"
    USSAMOA = "US/Samoa"
    UTC = "UTC"
    UNIVERSAL = "Universal"
    W_SU = "W-SU"
    WET = "WET"
    ZULU = "Zulu"

    def __str__(self) -> str:
        return str(self.value)
